==> 0.0.1+4.tar.gz: lib/audio/widget/image_background_gradient_widget.dart <==
import 'package:flutter/material.dart';
import 'package:palette_generator/palette_generator.dart';

/// The gradient background class. This class object is define to use as
/// the gradient background by detecting the color palette of the image
/// and use two color getting from the color palette to use as backdrop gradient.
/// Required: [image], [child]
class GradientBackground extends StatefulWidget {
  const GradientBackground(
      {super.key, required this.image, required this.child});

  final ImageProvider image;
  final Widget child;

  @override
  State<GradientBackground> createState() => _GradientBackgroundState();
}

class _GradientBackgroundState extends State<GradientBackground> {
  List<Color> colorsList = [];
  PaletteGenerator? generator;
  final Color lightVibrant = const Color.fromRGBO(197, 231, 255, 1.0);
  final Color lightMuted = const Color.fromRGBO(88, 130, 159, 1.0);

  @override
  void initState() {
    super.initState();
    getColorPalette();
  }

  /// The color palette generator. This method is use to generate color palette
  /// from the given [image]
  Future<void> getColorPalette() async {
    generator = await PaletteGenerator.fromImageProvider(widget.image);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    final List<Color> colors = [
      generator?.darkMutedColor?.color ?? lightMuted,
      generator?.vibrantColor?.color ?? lightMuted,
    ];

    return Scaffold(
        body: generator == null
            ? const Center(child: CircularProgressIndicator())
            : Container(
                decoration: BoxDecoration(
                    gradient: LinearGradient(
                        begin: Alignment.topRight,
                        end: Alignment.bottomLeft,
                        colors: colors)),
                child: widget.child,
              ));
  }
}

==> 0.0.2+11.tar.gz: lib/audio/widget/image_background_gradient_widget.dart <==
import 'package:flutter/material.dart';
import 'package:multimedia_gallery/extension/constants.dart';
import 'package:palette_generator/palette_generator.dart';

/// The gradient background class. This class object is define to use as
/// the gradient background by detecting the color palette of the image
/// and use two color getting from the color palette to use as backdrop gradient.
/// Required: [image], [child]
class GradientBackground extends StatefulWidget {
  const GradientBackground(
      {super.key, required this.image, required this.child});

  final ImageProvider image;
  final Widget child;

  @override
  State<GradientBackground> createState() => _GradientBackgroundState();
}

class _GradientBackgroundState extends State<GradientBackground> {
  List<Color> colorsList = [];
  PaletteGenerator? generator;

  @override
  void initState() {
    super.initState();
    getColorPalette();
  }

  /// The color palette generator. This method is use to generate color palette
  /// from the given [image]
  Future<void> getColorPalette() async {
    generator = await PaletteGenerator.fromImageProvider(widget.image);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    final List<Color> colors = [
      generator?.darkMutedColor?.color ?? lightMutedBlue,
      generator?.vibrantColor?.color ?? lightVibrantBlue,
    ];

    return Scaffold(
        body: generator == null
            ? loadingIndicator()
            : Container(
                decoration: BoxDecoration(
                    gradient: LinearGradient(
                        begin: Alignment.topRight,
                        end: Alignment.bottomLeft,
                        colors: colors)),
                child: widget.child,
              ));
  }
}
